==> alg-common-2.3.1-20190701.012317-3-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/HotActivitySelectorTest.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;



import junit.framework.TestCase;

import java.util.ArrayList;
import java.util.List;

public class HotActivitySelectorTest extends TestCase {
    protected void setUp() throws Exception {
        super.setUp();
        System.out.println();
    }

    protected void tearDown() throws Exception {
        super.tearDown();
        System.out.println();
    }

    public void testBayesianBandit() throws Exception { //几个候选集

        ActivityModel aam1 = new ActivityModel();
        aam1.activityId = 1815;
        aam1.activityType = 1; //活动类型 **new**
        aam1.alpha = 1.5; //模型参数
        aam1.beta = 2; // 模型参数
        aam1.reward = 0; //模型参数
        aam1.count = 0; //模型参数x
        aam1.isHot = true;

        ActivityModel aam2 = new ActivityModel();
        aam2.activityId = 1816;
        aam2.activityType = 1; //活动类型 **new**
        aam2.alpha = 1.5; //模型参数
        aam2.beta = 2; // 模型参数
        aam2.reward = 0; //模型参数
        aam2.count = 0; //模型参数-098rt6t-0rty
        aam2.isHot = false;



        ActivityData aad1 = new ActivityData();
        aad1.slotId = 1;
        aad1.appId = 1;
        aad1.activityId = 1815;
        aad1.changeScore = 0.015;
        aad1.isHot = true;
        aad1.uploadTime = 1558253647191l;

        Val val5 = new Val();
        val5.globalVal = 57;
        val5.appVal = 11;
        val5.slotVal = 8;
        aad1.hisSend = val5;  //发券

        //请求
        val5 = new Val();
        val5.globalVal = 80;
        val5.appVal = 70;
        val5.slotVal = 60;
        aad1.hisRequest = val5;

        //点击
        val5 = new Val();
        val5.globalVal = 44;
        val5.appVal = 7;
        val5.slotVal = 6;
        aad1.hisClick = val5;

        //消耗
        val5 = new Val();
        val5.globalVal = 80;
        val5.appVal = 60;
        val5.slotVal = 50;
        aad1.hisCost = val5;

        ActivityData aad2 = new ActivityData();
        aad2.slotId = 1;
        aad2.appId = 1;
        aad2.activityId = 1816;
        aad2.changeScore = 0.02;
        aad2.isHot = false;

        Val val6 = new Val();
        val6.globalVal = 400;
        val6.appVal = 300;
        val6.slotVal = 200;
        aad2.hisSend = val6;

        val6 = new Val();
        val6.globalVal = 5000;
        val6.appVal = 3500;
        val6.slotVal = 2800;
        aad2.hisRequest = val6;

        val6 = new Val();
        val6.globalVal = 2000;
        val6.appVal = 800;
        val6.slotVal = 600;
        aad2.hisClick = val6;

        val6 = new Val();
        val6.globalVal = 2000;
        val6.appVal = 900;
        val6.slotVal = 300;
        aad2.hisCost = val6;


        List<ActivityModel> actModel = new ArrayList<ActivityModel>();
        List<ActivityData> actData = new ArrayList<ActivityData>();
        actData.add(aad2);
        actData.add(aad1);
        actModel.add(aam2);
        actModel.add(aam1);


        //System.out.println("alistModel_0=" + actModel.get(0).activityId + " alistModel_1" + actModel.get(1).activityId);
        double gama = 0.05;
        int cnt1 = 0,cnt2 = 0;



      for (int i=0;i<=1000;i++){

          System.out.println(i);
          System.out.println("match=========================");

          //List<ActivityInfoModel> ActivityInfoModelList= match(actModel,actData, adList);


          System.out.println("select====================================");

          SelectActivityResult selectActivityResult=
              HotActivitySelector.hotSelect(actModel, actData,gama);
          ActivityModel activityModel = selectActivityResult.activityModel;
          List<SameCostActivitiesInfo>  sameCostActivitiesInfoList= selectActivityResult.sameCostActivitiesInfoList;

          System.out.println( i + " sameCostActivitiesInfoList: " + sameCostActivitiesInfoList);

          for (SameCostActivitiesInfo infos:sameCostActivitiesInfoList ){
              Long activityId = infos.activityId;
              int sameActivityCnt = infos.sameActivityCnt;
              Long activityType = infos.activityType;
              int ifSelected = infos.ifSelected;
              int index = infos.index;
              double mabReward = infos.mabReward;
              double changeScore = infos.changeScore;
              double diffChangeScore = infos.diffChangeScore;

              System.out.println( "activityId: "+ activityId + " sameActivityCnt: "+ sameActivityCnt + " activityType: "+ activityType
                      + " ifSelected: "+ ifSelected+ " index: "+ index+ " mabReward: "+ mabReward+ " changeScore: "+ changeScore
                      + " diffChangeScore: "+ diffChangeScore);}

          if (activityModel.activityId==1816){
              cnt1 +=1;
          }
          else {cnt2 +=1;}
      }

        System.out.println("cnt1816= "+cnt1);
        System.out.println("cnt1815= " +cnt2);

        double sumClickForms=99 ;
        int w1 = (int) (sumClickForms / 100 / 0.2);
        System.out.println("w1= "+ w1);

        /*
        Gson gs = new Gson();
        for(int i = 0;i<1000;i++)
        {
            String objectStr1 = gs.toJson(actData.get(0));//把对象转为JSON格式的字符串
            System.out.println("1815"+objectStr1);
            String objectStr2 = gs.toJson(actData.get(1));//把对象转为JSON格式的字符串

            System.out.println("1816"+objectStr2);
            System.out.println("***************");
            List<ActivityInfoModel>  act = bandit.match(actModel, actData, alisAd);

            objectStr1 = gs.toJson(act.get(0));//把对象转为JSON格式的字符串
            System.out.println("1815"+objectStr1);
            objectStr2 = gs.toJson(act.get(1));//把对象转为JSON格式的字符串
            System.out.println("1816"+objectStr2);
            break;
            System.out.println(gs.toJson(alisAd.get(0)));
            System.out.println(gs.toJson(alisAd.get(1)));
            for(ActivityInfoModel acm:act){
                System.out.println(acm.activityId);
            }
            System.out.println("--------------------------");
            ActivityModel actm = bandit.select(actModel,actData,0.05);
            String objectStr1 = gs.toJson(actModel.get(0));//把对象转为JSON格式的字符串
            System.out.println("actModel"+objectStr1);
            String objectStr2 = gs.toJson(actModel.get(1));//把对象转为JSON格式的字符串
            System.out.println("actModel"+objectStr2);


            String objectStr3 = gs.toJson(actData.get(0));//把对象转为JSON格式的字符串
            System.out.println("actData"+objectStr3);
            String objectStr4 = gs.toJson(actm);//把对象转为JSON格式的字符串
            System.out.println("actData"+objectStr4);
            System.out.println((i+1)+"th act = "+actm.activityId+" alpha="+act.alpha+" beta="+act.beta+" count="+act.count+" reward="+act.reward);
            System.out.println((i+1)+"th act = "+actm.activityId);

            if (actm.activityId == 1815) {
                actModel.set(1, actm);//update
                cnt2++;
            } else if (actm.activityId == 1816) {
                actModel.set(0, actm);
                cnt1++;
            }
            System.out.println("***********************");
            System.out.println("alpha="+m.alpha+"\t"+"beta="+m.beta+"\t"+"reward="+m.reward+" count="+"\t"+m.count+"\t");
            break;
        }
        System.out.println("1816 cnt1 = "+cnt1+"|| 1815 cnt2="+cnt2);
    }

    public Comparator<Integer> iComparator = new Comparator<Integer>() {

        @Override
        public int compare(Integer c1, Integer c2) {
            return (int) (c2 - c1);
        }
    };


*/
    }
}

==> alg-common-3.1.1-20190520.071121-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/HotActivitySelectorTest.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;



import junit.framework.TestCase;

import java.util.ArrayList;
import java.util.List;

public class HotActivitySelectorTest extends TestCase {
    protected void setUp() throws Exception {
        super.setUp();
        System.out.println();
    }

    protected void tearDown() throws Exception {
        super.tearDown();
        System.out.println();
    }

    public void testBayesianBandit() throws Exception { //几个候选集

        HotActivityModel aam1 = new HotActivityModel();
        aam1.activityId = 1815;
        aam1.activityType = 1; //活动类型 **new**
        aam1.alpha = 1.5; //模型参数
        aam1.beta = 2; // 模型参数
        aam1.reward = 0; //模型参数
        aam1.count = 0; //模型参数x
        aam1.isHot = true;

        HotActivityModel aam2 = new HotActivityModel();
        aam2.activityId = 1816;
        aam2.activityType = 1; //活动类型 **new**
        aam2.alpha = 1.5; //模型参数
        aam2.beta = 2; // 模型参数
        aam2.reward = 0; //模型参数
        aam2.count = 0; //模型参数-098rt6t-0rty
        aam2.isHot = false;



        HotActivityData aad1 = new HotActivityData();
        aad1.slotId = 1;
        aad1.appId = 1;
        aad1.activityId = 1815;
        aad1.changeScore = 0.01482;
        aad1.isHot = true;
        aad1.uploadTime = 1558086300000l;

        Val val5 = new Val();
        val5.globalVal = 57;
        val5.appVal = 11;
        val5.slotVal = 8;
        aad1.hisSend = val5;  //发券

        //请求
        val5 = new Val();
        val5.globalVal = 80;
        val5.appVal = 70;
        val5.slotVal = 60;
        aad1.hisRequest = val5;

        //点击
        val5 = new Val();
        val5.globalVal = 44;
        val5.appVal = 7;
        val5.slotVal = 6;
        aad1.hisClick = val5;

        //消耗
        val5 = new Val();
        val5.globalVal = 80;
        val5.appVal = 60;
        val5.slotVal = 50;
        aad1.hisCost = val5;

        HotActivityData aad2 = new HotActivityData();
        aad2.slotId = 1;
        aad2.appId = 1;
        aad2.activityId = 1816;
        aad2.changeScore = 0.02;
        aad2.isHot = false;

        Val val6 = new Val();
        val6.globalVal = 400;
        val6.appVal = 300;
        val6.slotVal = 200;
        aad2.hisSend = val6;

        val6 = new Val();
        val6.globalVal = 5000;
        val6.appVal = 3500;
        val6.slotVal = 2800;
        aad2.hisRequest = val6;

        val6 = new Val();
        val6.globalVal = 2000;
        val6.appVal = 800;
        val6.slotVal = 600;
        aad2.hisClick = val6;

        val6 = new Val();
        val6.globalVal = 2000;
        val6.appVal = 900;
        val6.slotVal = 300;
        aad2.hisCost = val6;


        List<HotActivityModel> actModel = new ArrayList<HotActivityModel>();
        List<HotActivityData> actData = new ArrayList<HotActivityData>();
        actData.add(aad2);
        actData.add(aad1);
        actModel.add(aam2);
        actModel.add(aam1);


        //System.out.println("alistModel_0=" + actModel.get(0).activityId + " alistModel_1" + actModel.get(1).activityId);
        double gama = 0.05;
        int cnt1 = 0,cnt2 = 0;



      for (int i=0;i<=1000;i++){

          System.out.println(i);
          System.out.println("match=========================");

          //List<HotActivityInfoModel> HotActivityInfoModelList= match(actModel,actData, adList);


          System.out.println("select====================================");

          HotSelectActivityResult HotSelectActivityResult= HotActivitySelector.hotSelect(actModel, actData,gama);
          HotActivityModel HotActivityModel = HotSelectActivityResult.hotActivityModel;
          List<SameCostActivitiesInfo>  sameCostActivitiesInfoList=HotSelectActivityResult.sameCostActivitiesInfoList;

          System.out.println( i + " sameCostActivitiesInfoList: " + sameCostActivitiesInfoList);

          for (SameCostActivitiesInfo infos:sameCostActivitiesInfoList ){
              Long activityId = infos.activityId;
              int sameActivityCnt = infos.sameActivityCnt;
              Long activityType = infos.activityType;
              int ifSelected = infos.ifSelected;
              int index = infos.index;
              double mabReward = infos.mabReward;
              double changeScore = infos.changeScore;
              double diffChangeScore = infos.diffChangeScore;

              System.out.println( "activityId: "+ activityId + " sameActivityCnt: "+ sameActivityCnt + " activityType: "+ activityType
                      + " ifSelected: "+ ifSelected+ " index: "+ index+ " mabReward: "+ mabReward+ " changeScore: "+ changeScore
                      + " diffChangeScore: "+ diffChangeScore);}

          if (HotActivityModel.activityId==1816){
              cnt1 +=1;
          }
          else {cnt2 +=1;}
      }

        System.out.println("cnt1816= "+cnt1);
        System.out.println("cnt1815= " +cnt2);

        double sumClickForms=99 ;
        int w1 = (int) (sumClickForms / 100 / 0.2);
        System.out.println("w1= "+ w1);

        /*
        Gson gs = new Gson();
        for(int i = 0;i<1000;i++)
        {
            String objectStr1 = gs.toJson(actData.get(0));//把对象转为JSON格式的字符串
            System.out.println("1815"+objectStr1);
            String objectStr2 = gs.toJson(actData.get(1));//把对象转为JSON格式的字符串

            System.out.println("1816"+objectStr2);
            System.out.println("***************");
            List<HotActivityInfoModel>  act = bandit.match(actModel, actData, alisAd);

            objectStr1 = gs.toJson(act.get(0));//把对象转为JSON格式的字符串
            System.out.println("1815"+objectStr1);
            objectStr2 = gs.toJson(act.get(1));//把对象转为JSON格式的字符串
            System.out.println("1816"+objectStr2);
            break;
            System.out.println(gs.toJson(alisAd.get(0)));
            System.out.println(gs.toJson(alisAd.get(1)));
            for(HotActivityInfoModel acm:act){
                System.out.println(acm.activityId);
            }
            System.out.println("--------------------------");
            HotActivityModel actm = bandit.select(actModel,actData,0.05);
            String objectStr1 = gs.toJson(actModel.get(0));//把对象转为JSON格式的字符串
            System.out.println("actModel"+objectStr1);
            String objectStr2 = gs.toJson(actModel.get(1));//把对象转为JSON格式的字符串
            System.out.println("actModel"+objectStr2);


            String objectStr3 = gs.toJson(actData.get(0));//把对象转为JSON格式的字符串
            System.out.println("actData"+objectStr3);
            String objectStr4 = gs.toJson(actm);//把对象转为JSON格式的字符串
            System.out.println("actData"+objectStr4);
            System.out.println((i+1)+"th act = "+actm.activityId+" alpha="+act.alpha+" beta="+act.beta+" count="+act.count+" reward="+act.reward);
            System.out.println((i+1)+"th act = "+actm.activityId);

            if (actm.activityId == 1815) {
                actModel.set(1, actm);//update
                cnt2++;
            } else if (actm.activityId == 1816) {
                actModel.set(0, actm);
                cnt1++;
            }
            System.out.println("***********************");
            System.out.println("alpha="+m.alpha+"\t"+"beta="+m.beta+"\t"+"reward="+m.reward+" count="+"\t"+m.count+"\t");
            break;
        }
        System.out.println("1816 cnt1 = "+cnt1+"|| 1815 cnt2="+cnt2);
    }

    public Comparator<Integer> iComparator = new Comparator<Integer>() {

        @Override
        public int compare(Integer c1, Integer c2) {
            return (int) (c2 - c1);
        }
    };


*/
    }
}
